@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011 Red Hat, Inc.
+ * Copyright (c) 2011, 2012 Red Hat, Inc.
  *
  * Gnome Documents is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -52,14 +52,13 @@ const TrackerController = imports.trackerController;
 const Tweener = imports.util.tweener;
 const Utils = imports.utils;
 const WindowMode = imports.windowMode;
+const ZpjMiner = imports.zpjMiner;
 
 const MINER_REFRESH_TIMEOUT = 60; /* seconds */
 
-function Application() {
-    this._init();
-}
+const Application = new Lang.Class({
+    Name: 'Application',
 
-Application.prototype = {
     _init: function() {
         Gettext.bindtextdomain('gnome-documents', Path.LOCALE_DIR);
         Gettext.textdomain('gnome-documents');
@@ -109,7 +108,9 @@ Application.prototype = {
             }));
         this.application.add_action(fsAction);
 
-        /* FIXME: use GSettings.create_action() once it's introspectable */
+        /* We can't use GSettings.create_action(), since we want to be able
+         * to control the enabled state of the action ourselves
+         */
         let viewAsAction = Gio.SimpleAction.new_stateful('view-as',
                                                          GLib.VariantType.new('s'),
                                                          Global.settings.get_value('view-as'));
@@ -121,6 +122,11 @@ Application.prototype = {
             function() {
                 viewAsAction.state = Global.settings.get_value('view-as');
             }));
+        Global.modeController.connect('window-mode-changed', Lang.bind(this,
+            function() {
+                let mode = Global.modeController.getWindowMode();
+                viewAsAction.set_enabled(mode == WindowMode.WindowMode.OVERVIEW);
+            }));
         this.application.add_action(viewAsAction);
 
 	let menu = new Gio.Menu();
@@ -140,16 +146,18 @@ Application.prototype = {
 	this.application.set_app_menu(menu);
     },
 
-    _refreshMinerNow: function() {
-        this._miner.RefreshDBRemote(DBus.CALL_FLAG_START, Lang.bind(this,
+    _refreshMinerNow: function(miner) {
+        miner.RefreshDBRemote(DBus.CALL_FLAG_START, Lang.bind(this,
             function(res, error) {
                 if (error) {
-                    log('Error updating the GData cache: ' + error.toString());
+                    log('Error updating the cache: ' + error.toString());
                     return;
                 }
 
                 Mainloop.timeout_add_seconds(MINER_REFRESH_TIMEOUT,
-                                             Lang.bind(this, this._refreshMinerNow));
+                                             Lang.bind(this, function() {
+                                                 this._refreshMinerNow(miner)
+                                             }));
             }));
 
         return false;
@@ -190,8 +198,12 @@ Application.prototype = {
         Global.notificationManager = new Notifications.NotificationManager();
 
         // startup a refresh of the gdocs cache
-        this._miner = new GDataMiner.GDataMiner();
-        this._refreshMinerNow();
+        let gdataMiner = new GDataMiner.GDataMiner();
+        this._refreshMinerNow(gdataMiner);
+
+        // startup a refresh of the skydrive cache
+        let zpjMiner = new ZpjMiner.ZpjMiner();
+        this._refreshMinerNow(zpjMiner);
 
         this._initMenus();
         this._mainWindow = new MainWindow.MainWindow(this.application);
@@ -223,4 +235,4 @@ Application.prototype = {
 
         return 0;
     }
-};
+});
