@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011 Red Hat, Inc.
+ * Copyright (c) 2011, 2012 Red Hat, Inc.
  *
  * Gnome Documents is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -27,6 +27,7 @@ const GData = imports.gi.GData;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
+const Zpj = imports.gi.Zpj;
 const _ = imports.gettext.gettext;
 
 const Lang = imports.lang;
@@ -41,11 +42,9 @@ const Searchbar = imports.searchbar;
 const TrackerUtils = imports.trackerUtils;
 const Utils = imports.utils;
 
-function SingleItemJob(doc) {
-    this._init(doc);
-}
+const SingleItemJob = new Lang.Class({
+    Name: 'SingleItemJob',
 
-SingleItemJob.prototype = {
     _init: function(urn) {
         this._urn = urn;
         this._cursor = null;
@@ -91,14 +90,12 @@ SingleItemJob.prototype = {
     _emitCallback: function() {
         this._callback(this._cursor);
     }
-};
-
-function DeleteItemJob(urn) {
-    this._init(urn);
-}
+});
 
+const DeleteItemJob = new Lang.Class({
+    Name: 'DeleteItemJob',
 // deletes the given resource
-DeleteItemJob.prototype = {
+
     _init: function(urn) {
         this._urn = urn;
     },
@@ -119,13 +116,12 @@ DeleteItemJob.prototype = {
                     this._callback();
             }));
     }
-};
+});
 
-function CollectionIconWatcher(collection) {
-    this._init(collection);
-}
 
-CollectionIconWatcher.prototype = {
+const CollectionIconWatcher = new Lang.Class({
+    Name: 'CollectionIconWatcher',
+
     _init: function(collection) {
         this._collection = collection;
         this._pixbuf = null;
@@ -265,14 +261,12 @@ CollectionIconWatcher.prototype = {
         this.destroy();
         this._start();
     }
-};
+});
 Signals.addSignalMethods(CollectionIconWatcher.prototype);
 
-function DocCommon(cursor) {
-    this._init(cursor);
-}
+const DocCommon = new Lang.Class({
+    Name: 'DocCommon',
 
-DocCommon.prototype = {
     _init: function(cursor) {
         this.id = null;
         this.uri = null;
@@ -604,21 +598,18 @@ DocCommon.prototype = {
 
         return retval;
     }
-};
+});
 Signals.addSignalMethods(DocCommon.prototype);
 
-function LocalDocument(cursor) {
-    this._init(cursor);
-}
-
-LocalDocument.prototype = {
-    __proto__: DocCommon.prototype,
+const LocalDocument = new Lang.Class({
+    Name: 'LocalDocument',
+    Extends: DocCommon,
 
     _init: function(cursor) {
         this._failedThumbnailing = false;
         this._triedThumbnailing = false;
 
-        DocCommon.prototype._init.call(this, cursor);
+        this.parent(cursor);
 
         this.sourceName = _("Local");
 
@@ -657,23 +648,20 @@ LocalDocument.prototype = {
             job.run(null);
         }
     }
-};
+});
 
 const _GOOGLE_DOCS_SCHEME_LABELS = "http://schemas.google.com/g/2005/labels";
 const _GOOGLE_DOCS_TERM_STARRED = "http://schemas.google.com/g/2005/labels#starred";
 
-function GoogleDocument(cursor) {
-    this._init(cursor);
-}
-
-GoogleDocument.prototype = {
-    __proto__: DocCommon.prototype,
+const GoogleDocument = new Lang.Class({
+    Name: 'GoogleDocument',
+    Extends: DocCommon,
 
     _init: function(cursor) {
         this._triedThumbnailing = true;
         this._failedThumbnailing = true;
 
-        DocCommon.prototype._init.call(this, cursor);
+        this.parent(cursor);
 
         // overridden
         this.defaultAppName = _("Google Docs");
@@ -729,11 +717,11 @@ GoogleDocument.prototype = {
                     return;
                 }
 
-                Gd.pdf_loader_load_entry_async
+                Gd.pdf_loader_load_gdata_entry_async
                     (entry, service, cancellable, Lang.bind(this,
                         function(source, res) {
                             try {
-                                let document = Gd.pdf_loader_load_entry_finish(res);
+                                let document = Gd.pdf_loader_load_gdata_entry_finish(res);
                                 callback(this, document, null);
                             } catch (e) {
                                 callback(this, null, e);
@@ -760,11 +748,11 @@ GoogleDocument.prototype = {
     populateFromCursor: function(cursor) {
         this.shared = cursor.get_boolean(Query.QueryColumns.SHARED);
 
-        DocCommon.prototype.populateFromCursor.call(this, cursor);
+        this.parent(cursor);
     },
 
     setFavorite: function(favorite) {
-        DocCommon.prototype.setFavorite.call(this, favorite);
+        this.parent(favorite);
 
         this._createGDataEntry(null, Lang.bind(this,
             function(entry, service, exception) {
@@ -806,17 +794,118 @@ GoogleDocument.prototype = {
     canTrash: function() {
         return false;
     }
-};
+});
+
+function SkydriveDocument(cursor) {
+    this._init(cursor);
+}
+
+SkydriveDocument.prototype = {
+    __proto__: DocCommon.prototype,
+
+    _init: function(cursor) {
+        this._triedThumbnailing = true;
+        this._failedThumbnailing = true;
+
+        DocCommon.prototype._init.call(this, cursor);
+
+        // overridden
+        this.defaultAppName = _("Skydrive");
+        this.sourceName = _("Skydrive");
+    },
+
+    _createZpjEntry: function(cancellable, callback) {
+        let source = Global.sourceManager.getItemById(this.resourceUrn);
+
+        let authorizer = new Zpj.GoaAuthorizer({ goa_object: source.object });
+        let service = new Zpj.Skydrive({ authorizer: authorizer });
+
+        const zpj_prefix = "windows-live:skydrive:";
+        let zpj_id = this.identifier.substring(zpj_prefix.length);
+
+        service.query_info_from_id_async
+            (zpj_id, cancellable,
+             Lang.bind(this,
+                 function(object, res) {
+                     let entry = null;
+                     let exception = null;
+
+                     try {
+                         entry = object.query_info_from_id_finish(res);
+                     } catch (e) {
+                         exception = e;
+                     }
+
+                     callback(entry, service, exception);
+                 }));
+    },
+
+    load: function(cancellable, callback) {
+        this._createZpjEntry(cancellable, Lang.bind(this,
+            function(entry, service, exception) {
+                if (exception) {
+                    // try loading from the most recent cache, if any
+                    Gd.pdf_loader_load_uri_async(this.identifier, cancellable, Lang.bind(this,
+                        function(source, res) {
+                            try {
+                                let document = Gd.pdf_loader_load_uri_finish(res);
+                                callback(this, document, null);
+                            } catch (e) {
+                                // report the outmost error only
+                                callback(this, null, exception);
+                                return;
+                            }
+                        }));
+
+                    return;
+                }
+
+                Gd.pdf_loader_load_zpj_entry_async
+                    (entry, service, cancellable, Lang.bind(this,
+                        function(source, res) {
+                            try {
+                                let document = Gd.pdf_loader_load_zpj_entry_finish(res);
+                                callback(this, document, null);
+                            } catch (e) {
+                                callback(this, null, e);
+                            }
+                        }));
+            }));
+    },
+
+    updateTypeDescription: function() {
+        let description;
+
+        if (this.rdfType.indexOf('nfo#Spreadsheet') != -1)
+            description = _("Spreadsheet");
+        else if (this.rdfType.indexOf('nfo#Presentation') != -1)
+            description = _("Presentation");
+        else if (this.rdfType.indexOf('nfo#DataContainer') != -1)
+            description = _("Collection");
+        else
+            description = _("Document");
+
+        this.typeDescription = description;
+    },
+
+    setFavorite: function(favorite) {
+    },
+
+    canTrash: function() {
+        return false;
+    }
+}
 
 function DocumentManager() {
     this._init();
 }
 
-DocumentManager.prototype = {
-    __proto__: Manager.BaseManager.prototype,
+const DocumentManager = new Lang.Class({
+    Name: 'DocumentManager',
+    Extends: Manager.BaseManager,
 
     _init: function() {
-        Manager.BaseManager.prototype._init.call(this);
+        this.parent();
 
         this._model = new DocumentModel();
 
@@ -867,12 +956,19 @@ DocumentManager.prototype = {
                 (identifier.indexOf('https://docs.google.com') != -1));
     },
 
+    _identifierIsSkydrive: function(identifier) {
+        return (identifier &&
+                (identifier.indexOf('windows-live:skydrive:') != -1));
+    },
+
     createDocumentFromCursor: function(cursor) {
         let identifier = cursor.get_string(Query.QueryColumns.IDENTIFIER)[0];
         let doc;
 
         if (this._identifierIsGoogle(identifier))
             doc = new GoogleDocument(cursor);
+        else if (this._identifierIsSkydrive(identifier))
+            doc = new SkydriveDocument(cursor);
         else
             doc = new LocalDocument(cursor);
 
@@ -896,12 +992,12 @@ DocumentManager.prototype = {
             items[idx].destroy();
         };
 
-        Manager.BaseManager.prototype.clear.call(this);
+        this.parent();
         this._model.clear();
     },
 
     setActiveItem: function(doc) {
-        if (Manager.BaseManager.prototype.setActiveItem.call(this, doc)) {
+        if (this.parent(doc)) {
 
             if (doc && !doc.collection) {
                 let recentManager = Gtk.RecentManager.get_default();
@@ -913,13 +1009,11 @@ DocumentManager.prototype = {
     getModel: function() {
         return this._model;
     }
-};
+});
 
-function DocumentModel() {
-    this._init();
-}
+const DocumentModel = new Lang.Class({
+    Name: 'DocumentModel',
 
-DocumentModel.prototype = {
     _init: function() {
         this.model = Gd.create_list_store();
         this.model.set_sort_column_id(Gd.MainColumns.MTIME,
@@ -969,4 +1063,4 @@ DocumentModel.prototype = {
                 return false;
             }));
     }
-};
+});
